==> frogml-0.10.10.tar.gz: frogml-0.10.10/tests/frogml/scikit_learn/test_scikit_learn_model.py <==
import json
import os.path
import platform
import tempfile
from pathlib import Path
from unittest.mock import patch, ANY, MagicMock

import sklearn
import joblib
import pytest
from frogml_proto.qwak.jfrog.gateway.v0.repository_pb2 import RepositorySpec
from frogml_services_mock import frogml_services_mock
from frogml_services_mock.mocks.frogml_mocks import FrogmlMocks
from frogml_storage.frog_ml import FrogMLStorage
from onnx import ModelProto

from frogml.scikit_learn import (
    log_model,
    _SCIKIT_LEARN_MODEL_FLAVOR,
    get_model_info,
    load_model,
)
from tests.frogml.utils.test_files_tools import given_full_path_to_file


@patch.object(FrogMLStorage, "__init__", lambda _: None)
@patch("frogml_storage.frog_ml.FrogMLStorage.upload_model_version")
@patch("shutil.rmtree")
def test_log_model(
    mock_shutil_rmtree, mock_frog_ml, jf_project: str, frogml_services_mock: FrogmlMocks
):
    # Given
    repository = "repository"
    model_name = "name"
    version = "version"
    properties = {"key": "value"}
    dependencies = ["pandas==1.2.3"]
    code_dir = "../../../tests/frogml/scikit_learn"
    model_dir = "../../../tests/resources/models/scikit_learn"
    full_code_dir = given_full_path_to_file(file_name=code_dir)

    full_model_dir = given_full_path_to_file(file_name=model_dir)
    loaded_model = joblib.load(
        os.path.join(full_model_dir, "random_forest_model.joblib")
    )
    frogml_services_mock.repository_service.repositories[repository] = RepositorySpec(
        project_key=jf_project
    )

    # When
    log_model(
        model=loaded_model,
        model_name=model_name,
        repository=repository,
        version=version,
        properties=properties,
        dependencies=dependencies,
        code_dir=full_code_dir,
    )

    # Then
    # validate passed arguments
    mock_frog_ml.assert_called_once_with(
        repository=repository,
        model_name=model_name,
        model_path=ANY,
        model_type=ANY,
        version=version,
        properties=properties,
        dependencies_files_paths=ANY,
        code_archive_file_path=ANY,
    )

    # validate model type
    model_metadata = mock_frog_ml.call_args.kwargs["model_type"]
    assert model_metadata.framework == _SCIKIT_LEARN_MODEL_FLAVOR
    assert model_metadata.framework_version == sklearn.__version__
    assert model_metadata.serialization_format == "joblib"
    assert model_metadata.runtime == "python"
    assert model_metadata.runtime_version == platform.python_version()

    # validate dependencies
    dependencies_files_paths = mock_frog_ml.call_args.kwargs[
        "dependencies_files_paths"
    ][0]
    with open(dependencies_files_paths, "r") as dependencies_file:
        dependencies_list = [line.strip() for line in dependencies_file.readlines()]
        assert len(dependencies_list) == len(dependencies)
        for dependency in dependencies:
            assert dependency in dependencies_list

    # validate code archive
    archive_path = Path(mock_frog_ml.call_args.kwargs["code_archive_file_path"])
    assert archive_path.exists()
    assert archive_path.suffix == ".zip"


@patch.object(FrogMLStorage, "__init__", lambda _: None)
@patch("frogml_storage.frog_ml.FrogMLStorage.get_entity_manifest")
def test_get_model_info(get_entity_info_mock):
    # Given
    repository = "repository"
    model_name = "model_name"
    version = "version"
    json_file_path = (
        "../../../tests/resources/models/scikit_learn/scikit_learn_model_info.json"
    )
    json_full_path = given_full_path_to_file(file_name=json_file_path)

    with open(json_full_path, "r") as json_file:
        model_info = json.load(json_file)

    get_entity_info_mock.return_value = model_info

    # When
    actual_result = get_model_info(
        repository=repository, model_name=model_name, version=version
    )

    # Then
    assert actual_result == model_info


@patch.object(FrogMLStorage, "__init__", lambda _: None)
@patch("frogml_storage.frog_ml.FrogMLStorage.get_entity_manifest")
@patch("frogml_storage.frog_ml.FrogMLStorage.download_model_version")
def test_load_model(download_model_version_mock, get_entity_info_mock):
    # Given
    repository = "repository"
    model_name = "random_forest_model"
    version = "version"
    json_file_path = (
        "../../../tests/resources/models/scikit_learn/scikit_learn_model_info.json"
    )
    full_json_path = given_full_path_to_file(file_name=json_file_path)

    with open(full_json_path, "r") as json_file:
        model_info = json.load(json_file)

    get_entity_info_mock.return_value = model_info
    full_model_dir_path = given_full_path_to_file(
        file_name="../../../tests/resources/models/scikit_learn"
    )
    download_model_version_mock.return_value = Path(full_model_dir_path)

    # When
    with patch.object(tempfile, "TemporaryDirectory") as mock_tempdir:
        mock_tempdir_instance = MagicMock()
        mock_tempdir.return_value = mock_tempdir_instance
        mock_tempdir_instance.__enter__.return_value = full_model_dir_path
        download_model_version_mock.return_value = Path(full_model_dir_path)
        deserialized_model = load_model(
            repository=repository, model_name=model_name, version=version
        )

        # Then
        isinstance(deserialized_model, ModelProto)


@patch.object(FrogMLStorage, "__init__", lambda _: None)
@patch("frogml_storage.frog_ml.FrogMLStorage.get_entity_manifest")
@patch("frogml_storage.frog_ml.FrogMLStorage.download_model_version")
def test_load_model_failed_deserialized(
    download_model_version_mock, get_entity_info_mock
):
    # Given
    repository = "repository"
    model_name = "random_forest_model"
    version = "version"
    json_file_path = (
        "../../../tests/resources/models/scikit_learn/scikit_learn_model_info.json"
    )
    full_json_path = given_full_path_to_file(file_name=json_file_path)

    with open(full_json_path, "r") as json_file:
        model_info = json.load(json_file)

    get_entity_info_mock.return_value = model_info
    full_model_dir_path = given_full_path_to_file(
        file_name="../../../tests/resources/models/files"
    )
    download_model_version_mock.return_value = Path(full_model_dir_path)

    # When + Then
    with pytest.raises(Exception):
        load_model(repository=repository, model_name=model_name, version=version)

==> frogml-1.0.0.tar.gz: frogml-1.0.0/tests/frogml/scikit_learn/test_scikit_learn_model.py <==
import json
import os.path
import platform
import tempfile
from pathlib import Path
from unittest.mock import patch, ANY, MagicMock

import joblib
import pytest
import sklearn
from frogml_proto.qwak.jfrog.gateway.v0.repository_pb2 import RepositorySpec
from frogml_services_mock import frogml_services_mock
from frogml_services_mock.mocks.frogml_mocks import FrogmlMocks
from frogml_storage.frog_ml import FrogMLStorage
from onnx import ModelProto

from frogml.scikit_learn import (
    log_model,
    _SCIKIT_LEARN_MODEL_FLAVOR,
    get_model_info,
    load_model,
)
from tests.frogml.utils.test_files_tools import given_full_path_to_file


@patch.object(FrogMLStorage, "__init__", lambda _: None)
@patch("frogml_storage.frog_ml.FrogMLStorage.upload_model_version")
@patch("shutil.rmtree")
def test_log_model(
    mock_shutil_rmtree,
    mock_frog_ml,
    jf_project: str,
    frogml_services_mock: FrogmlMocks,
    models_resources_dir_path: str,
):
    # Given
    repository = "repository"
    model_name = "name"
    version = "version"
    properties = {"key": "value"}
    dependencies = ["pandas==1.2.3"]
    full_code_dir = os.path.join(models_resources_dir_path, "classes")

    full_model_dir = os.path.join(models_resources_dir_path, "scikit_learn")
    loaded_model = joblib.load(
        os.path.join(full_model_dir, "random_forest_model.joblib")
    )
    frogml_services_mock.repository_service.repositories[repository] = RepositorySpec(
        project_key=jf_project
    )

    # When
    log_model(
        model=loaded_model,
        model_name=model_name,
        repository=repository,
        version=version,
        properties=properties,
        dependencies=dependencies,
        code_dir=full_code_dir,
    )

    # Then
    # validate passed arguments
    mock_frog_ml.assert_called_once_with(
        repository=repository,
        model_name=model_name,
        model_path=ANY,
        model_type=ANY,
        version=version,
        properties=properties,
        dependencies_files_paths=ANY,
        code_archive_file_path=ANY,
    )

    # validate model type
    model_metadata = mock_frog_ml.call_args.kwargs["model_type"]
    assert model_metadata.framework == _SCIKIT_LEARN_MODEL_FLAVOR
    assert model_metadata.framework_version == sklearn.__version__
    assert model_metadata.serialization_format == "joblib"
    assert model_metadata.runtime == "python"
    assert model_metadata.runtime_version == platform.python_version()

    # validate dependencies
    dependencies_files_paths = mock_frog_ml.call_args.kwargs[
        "dependencies_files_paths"
    ][0]
    with open(dependencies_files_paths, "r") as dependencies_file:
        dependencies_list = [line.strip() for line in dependencies_file.readlines()]
        assert len(dependencies_list) == len(dependencies)
        for dependency in dependencies:
            assert dependency in dependencies_list

    # validate code archive
    archive_path = Path(mock_frog_ml.call_args.kwargs["code_archive_file_path"])
    assert archive_path.exists()
    assert archive_path.suffix == ".zip"


@patch.object(FrogMLStorage, "__init__", lambda _: None)
@patch("frogml_storage.frog_ml.FrogMLStorage.get_entity_manifest")
def test_get_model_info(get_entity_info_mock):
    # Given
    repository = "repository"
    model_name = "model_name"
    version = "version"
    json_file_path = (
        "../../../tests/resources/models/scikit_learn/scikit_learn_model_info.json"
    )
    json_full_path = given_full_path_to_file(file_name=json_file_path)

    with open(json_full_path, "r") as json_file:
        model_info = json.load(json_file)

    get_entity_info_mock.return_value = model_info

    # When
    actual_result = get_model_info(
        repository=repository, model_name=model_name, version=version
    )

    # Then
    assert actual_result == model_info


@patch.object(FrogMLStorage, "__init__", lambda _: None)
@patch("frogml_storage.frog_ml.FrogMLStorage.get_entity_manifest")
@patch("frogml_storage.frog_ml.FrogMLStorage.download_model_version")
def test_load_model(download_model_version_mock, get_entity_info_mock):
    # Given
    repository = "repository"
    model_name = "random_forest_model"
    version = "version"
    json_file_path = (
        "../../../tests/resources/models/scikit_learn/scikit_learn_model_info.json"
    )
    full_json_path = given_full_path_to_file(file_name=json_file_path)

    with open(full_json_path, "r") as json_file:
        model_info = json.load(json_file)

    get_entity_info_mock.return_value = model_info
    full_model_dir_path = given_full_path_to_file(
        file_name="../../../tests/resources/models/scikit_learn"
    )
    download_model_version_mock.return_value = Path(full_model_dir_path)

    # When
    with patch.object(tempfile, "TemporaryDirectory") as mock_tempdir:
        mock_tempdir_instance = MagicMock()
        mock_tempdir.return_value = mock_tempdir_instance
        mock_tempdir_instance.__enter__.return_value = full_model_dir_path
        download_model_version_mock.return_value = Path(full_model_dir_path)
        deserialized_model = load_model(
            repository=repository, model_name=model_name, version=version
        )

        # Then
        isinstance(deserialized_model, ModelProto)


@patch.object(FrogMLStorage, "__init__", lambda _: None)
@patch("frogml_storage.frog_ml.FrogMLStorage.get_entity_manifest")
@patch("frogml_storage.frog_ml.FrogMLStorage.download_model_version")
def test_load_model_failed_deserialized(
    download_model_version_mock, get_entity_info_mock
):
    # Given
    repository = "repository"
    model_name = "random_forest_model"
    version = "version"
    json_file_path = (
        "../../../tests/resources/models/scikit_learn/scikit_learn_model_info.json"
    )
    full_json_path = given_full_path_to_file(file_name=json_file_path)

    with open(full_json_path, "r") as json_file:
        model_info = json.load(json_file)

    get_entity_info_mock.return_value = model_info
    full_model_dir_path = given_full_path_to_file(
        file_name="../../../tests/resources/models/files"
    )
    download_model_version_mock.return_value = Path(full_model_dir_path)

    # When + Then
    with pytest.raises(Exception):
        load_model(repository=repository, model_name=model_name, version=version)
